@@ -390,7 +390,7 @@ class Cache(GObject.GObject):
             try:
                 Gio.file_new_for_path(self.cache_dir).make_directory(None)
             except GLib.Error as error:
-                logger.warn(
+                logger.warning(
                     "Error: {}, {}".format(error.domain, error.message))
                 return
 
@@ -408,7 +408,7 @@ class Cache(GObject.GObject):
         if (success
                 and thumb_file.query_exists()):
             thumb_file.read_async(
-                GLib.PRIORITY_HIGH, None, self._open_stream, None)
+                GLib.PRIORITY_LOW, None, self._open_stream, None)
             return
 
         self.emit('miss')
@@ -418,9 +418,9 @@ class Cache(GObject.GObject):
         try:
             stream = thumb_file.read_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             stream.close_async(
-                GLib.PRIORITY_HIGH, None, self._close_stream, None)
+                GLib.PRIORITY_LOW, None, self._close_stream, None)
             self.emit('miss')
             return
 
@@ -432,13 +432,13 @@ class Cache(GObject.GObject):
         try:
             pixbuf = GdkPixbuf.Pixbuf.new_from_stream_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             stream.close_async(
-                GLib.PRIORITY_HIGH, None, self._close_stream, None)
+                GLib.PRIORITY_LOW, None, self._close_stream, None)
             self.emit('miss')
             return
 
-        stream.close_async(GLib.PRIORITY_HIGH, None, self._close_stream, None)
+        stream.close_async(GLib.PRIORITY_LOW, None, self._close_stream, None)
         self.emit('hit', pixbuf)
 
     @log
@@ -446,7 +446,7 @@ class Cache(GObject.GObject):
         try:
             stream.close_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
 
 
 class EmbeddedArt(GObject.GObject):
@@ -472,7 +472,7 @@ class EmbeddedArt(GObject.GObject):
             Gst.init(None)
             GstPbutils.pb_utils_init()
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             return
 
         self._media_art = MediaArt.Process.new()
@@ -499,7 +499,7 @@ class EmbeddedArt(GObject.GObject):
         try:
             discoverer = GstPbutils.Discoverer.new(Gst.SECOND)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             self._lookup_cover_in_directory()
             return
 
@@ -518,7 +518,7 @@ class EmbeddedArt(GObject.GObject):
         success = discoverer.discover_uri_async(self._media.get_url())
 
         if not success:
-            logger.warn("Could not add url to discoverer.")
+            logger.warning("Could not add url to discoverer.")
             self.emit('unavailable')
             discoverer.stop()
             return
@@ -535,8 +535,8 @@ class EmbeddedArt(GObject.GObject):
         if (error is not None
                 or tags is None):
             if error:
-                logger.warn(
-                    "Discoverer error: {}, {}", error.domain, error.message)
+                logger.warning("Discoverer error: {}, {}".format(
+                    Gst.CoreError(error.code), error.message))
             discoverer.stop()
             self.emit('unavailable')
             return
@@ -566,7 +566,7 @@ class EmbeddedArt(GObject.GObject):
                 discoverer.stop()
                 return
             except GLib.Error as error:
-                logger.warn("Error: {}, {}".format(
+                logger.warning("Error: {}, {}".format(
                     MediaArt.Error(error.code), error.message))
 
         discoverer.stop()
@@ -579,7 +579,7 @@ class EmbeddedArt(GObject.GObject):
         self._media_art.uri_async(
             MediaArt.Type.ALBUM, MediaArt.ProcessFlags.NONE,
             self._media.get_url(), self._artist, self._album,
-            GLib.PRIORITY_HIGH, None, self._uri_async_cb, None)
+            GLib.PRIORITY_LOW, None, self._uri_async_cb, None)
 
     @log
     def _uri_async_cb(self, src, result, data):
@@ -639,19 +639,19 @@ class RemoteArt(GObject.GObject):
         try:
             src.delete_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
 
     @log
     def _splice_callback(self, src, result, data):
         tmp_file, iostream = data
 
         iostream.close_async(
-            GLib.PRIORITY_HIGH, None, self._close_iostream_callback, None)
+            GLib.PRIORITY_LOW, None, self._close_iostream_callback, None)
 
         try:
             src.splice_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             self.emit('unavailable')
             return
 
@@ -666,35 +666,35 @@ class RemoteArt(GObject.GObject):
             # FIXME: I/O blocking
             MediaArt.file_to_jpeg(tmp_file.get_path(), cache_path)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             self.emit('unavailable')
             return
 
         self.emit('retrieved')
 
         tmp_file.delete_async(
-            GLib.PRIORITY_HIGH, None, self._delete_callback, None)
+            GLib.PRIORITY_LOW, None, self._delete_callback, None)
 
     @log
     def _close_iostream_callback(self, src, result, data):
         try:
             src.close_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
 
     @log
     def _read_callback(self, src, result, data):
         try:
             istream = src.read_finish(result)
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             self.emit('unavailable')
             return
 
         try:
             [tmp_file, iostream] = Gio.File.new_tmp()
         except GLib.Error as error:
-            logger.warn("Error: {}, {}".format(error.domain, error.message))
+            logger.warning("Error: {}, {}".format(error.domain, error.message))
             self.emit('unavailable')
             return
 
@@ -703,13 +703,13 @@ class RemoteArt(GObject.GObject):
         # closed. PyGI specific issue?
         ostream.splice_async(
             istream, Gio.OutputStreamSpliceFlags.CLOSE_SOURCE |
-            Gio.OutputStreamSpliceFlags.CLOSE_TARGET, GLib.PRIORITY_HIGH,
+            Gio.OutputStreamSpliceFlags.CLOSE_TARGET, GLib.PRIORITY_LOW,
             None, self._splice_callback, [tmp_file, iostream])
 
     @log
     def _remote_album_art(self, source, param, item, count, error):
         if error:
-            logger.warn("Grilo error {}".format(error))
+            logger.warning("Grilo error {}".format(error))
             self.emit('unavailable')
             return
 
@@ -721,4 +721,4 @@ class RemoteArt(GObject.GObject):
 
         src = Gio.File.new_for_uri(thumb_uri)
         src.read_async(
-            GLib.PRIORITY_HIGH, None, self._read_callback, None)
+            GLib.PRIORITY_LOW, None, self._read_callback, None)
