@@ -22,6 +22,8 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
+from queue import LifoQueue
+
 from gettext import gettext as _
 from gi.repository import GLib, GObject, Gtk, Gdk
 
@@ -43,6 +45,8 @@ class AlbumsView(BaseView):
     @log
     def __init__(self, window, player):
         super().__init__('albums', _("Albums"), window, None)
+
+        self._queue = LifoQueue()
         self._album_widget = AlbumWidget(player, self)
         self.player = player
         self.add(self._album_widget)
@@ -55,7 +59,7 @@ class AlbumsView(BaseView):
 
     @log
     def _on_changes_pending(self, data=None):
-        if (self._init and not self._header_bar._selectionMode):
+        if (self._init and not self._header_bar.selection_mode):
             self._offset = 0
             self._init = True
             GLib.idle_add(self.populate)
@@ -63,7 +67,7 @@ class AlbumsView(BaseView):
 
     @log
     def _on_selection_mode_changed(self, widget, data=None):
-        if (not self._header_bar._selectionMode
+        if (not self._header_bar.selection_mode
                 and grilo.changes_pending['Albums']):
             self._on_changes_pending()
 
@@ -75,6 +79,7 @@ class AlbumsView(BaseView):
             margin=18, row_spacing=12, column_spacing=6,
             min_children_per_line=1, max_children_per_line=25)
 
+        self._view.get_style_context().add_class('content-view')
         self._view.connect('child-activated', self._on_child_activated)
 
         scrolledwin = Gtk.ScrolledWindow()
@@ -147,9 +152,21 @@ class AlbumsView(BaseView):
             child = self._create_album_item(item)
             self._view.add(child)
         elif remaining == 0:
-            self._window.notifications_popup.pop_loading()
             self._view.show()
 
+            # FIXME: To work around slow updating of the albumsview,
+            # load album covers with a fixed delay. This results in a
+            # quick first show with a placeholder cover and then a
+            # reasonably responsive view while loading the actual
+            # covers.
+            while not self._queue.empty():
+                func, arg = self._queue.get()
+                GLib.timeout_add(
+                    65 * self._queue.qsize(), func, arg,
+                    priority=GLib.PRIORITY_LOW)
+
+            self._window.notifications_popup.pop_loading()
+
     def _create_album_item(self, item):
         artist = utils.get_artist_name(item)
         title = utils.get_media_title(item)
@@ -158,6 +175,7 @@ class AlbumsView(BaseView):
             '/org/gnome/Music/AlbumCover.ui')
 
         child = Gtk.FlowBoxChild()
+        child.get_style_context().add_class('tile')
         child.stack = builder.get_object('stack')
         child.check = builder.get_object('check')
         child.title = builder.get_object('title')
@@ -185,7 +203,7 @@ class AlbumsView(BaseView):
         child.show()
 
         cover_stack = CoverStack(child.stack, Art.Size.MEDIUM)
-        cover_stack.update(item)
+        self._queue.put((cover_stack.update, item))
 
         return child
 
