@@ -67,16 +67,15 @@ class Window(Gtk.ApplicationWindow):
     def __init__(self, app):
         super().__init__(application=app, title=_("Music"))
 
-        self.connect('focus-in-event', self._windows_focus_cb)
         self.settings = Gio.Settings.new('org.gnome.Music')
         self.add_action(self.settings.create_action('repeat'))
-        selectAll = Gio.SimpleAction.new('selectAll', None)
-        app.set_accels_for_action('win.selectAll', ['<Primary>a'])
-        selectAll.connect('activate', self._on_select_all)
-        self.add_action(selectAll)
-        selectNone = Gio.SimpleAction.new('selectNone', None)
-        selectNone.connect('activate', self._on_select_none)
-        self.add_action(selectNone)
+        select_all = Gio.SimpleAction.new('select_all', None)
+        select_all.connect('activate', self._select_all)
+        self.add_action(select_all)
+        select_none = Gio.SimpleAction.new('select_none', None)
+        select_none.connect('activate', self._select_none)
+        self.add_action(select_none)
+
         self.set_size_request(200, 100)
         self.set_default_icon_name('gnome-music')
 
@@ -100,6 +99,9 @@ class Window(Gtk.ApplicationWindow):
         self.notifications_popup = NotificationsPopup()
         self._overlay.add_overlay(self.notifications_popup)
 
+        self._media_keys_proxy = None
+        self._init_media_keys_proxy()
+
         self.window_size_update_timeout = None
         self.connect("window-state-event", self._on_window_state_event)
         self.connect("configure-event", self._on_configure_event)
@@ -117,7 +119,7 @@ class Window(Gtk.ApplicationWindow):
                     self.toolbar._search_button.set_sensitive(True)
                     self.toolbar._select_button.set_sensitive(True)
                     self.toolbar.show_stack()
-            elif (self.toolbar._selectionMode is False
+            elif (self.toolbar.selection_mode is False
                     and len(self.views) != 1):
                 self._stack.disconnect(self._on_notify_model_id)
                 self.disconnect(self._key_press_event_id)
@@ -151,42 +153,61 @@ class Window(Gtk.ApplicationWindow):
         self.settings.set_boolean('window-maximized', 'GDK_WINDOW_STATE_MAXIMIZED' in event.new_window_state.value_names)
 
     @log
-    def _grab_media_player_keys(self):
-        self.proxy = Gio.DBusProxy.new_sync(Gio.bus_get_sync(Gio.BusType.SESSION, None),
-                                            Gio.DBusProxyFlags.NONE,
-                                            None,
-                                            'org.gnome.SettingsDaemon.MediaKeys',
-                                            '/org/gnome/SettingsDaemon/MediaKeys',
-                                            'org.gnome.SettingsDaemon.MediaKeys',
-                                            None)
-        self.proxy.call_sync('GrabMediaPlayerKeys',
-                             GLib.Variant('(su)', ('Music', 0)),
-                             Gio.DBusCallFlags.NONE,
-                             -1,
-                             None)
-        self.proxy.connect('g-signal', self._handle_media_keys)
+    def _init_media_keys_proxy(self):
+        def name_appeared(connection, name, name_owner, data=None):
+            Gio.DBusProxy.new_for_bus(
+                Gio.BusType.SESSION,
+                Gio.DBusProxyFlags.DO_NOT_LOAD_PROPERTIES, None,
+                "org.gnome.SettingsDaemon.MediaKeys",
+                "/org/gnome/SettingsDaemon/MediaKeys",
+                "org.gnome.SettingsDaemon.MediaKeys", None,
+                self._media_keys_proxy_ready)
+
+        Gio.bus_watch_name(
+            Gio.BusType.SESSION, "org.gnome.SettingsDaemon.MediaKeys",
+            Gio.BusNameWatcherFlags.NONE, name_appeared, None)
 
     @log
-    def _windows_focus_cb(self, window, event):
+    def _media_keys_proxy_ready(self, proxy, result, data=None):
         try:
-            self._grab_media_player_keys()
-        except GLib.GError:
-            # We cannot grab media keys if no settings daemon is running
-            pass
+            self._media_keys_proxy = proxy.new_finish(result)
+        except GLib.Error as e:
+            logger.warning(
+                "Error: Failed to contact settings daemon:", e.message)
+            return
+
+        self._grab_media_player_keys()
+        self._media_keys_proxy.connect(
+            "g-signal", self._handle_media_keys)
+        self.connect("focus-in-event", self._grab_media_player_keys)
+
+    @log
+    def _grab_media_player_keys(self, window=None, event=None):
+        def proxy_call_finished(proxy, result, data=None):
+            try:
+                proxy.call_finish(result)
+            except GLib.Error as e:
+                logger.warning(
+                    "Error: Failed to grab mediaplayer keys: {}".format(
+                        e.message))
+
+        self._media_keys_proxy.call(
+            "GrabMediaPlayerKeys", GLib.Variant("(su)", ("Music", 0)),
+            Gio.DBusCallFlags.NONE, -1, None, proxy_call_finished)
 
     @log
     def _handle_media_keys(self, proxy, sender, signal, parameters):
-        if signal != 'MediaPlayerKeyPressed':
-            print('Received an unexpected signal \'%s\' from media player'.format(signal))
+        app, response = parameters.unpack()
+        if app != "Music":
             return
-        response = parameters.get_child_value(1).get_string()
-        if 'Play' in response:
+
+        if "Play" in response:
             self.player.play_pause()
-        elif 'Stop' in response:
+        elif "Stop" in response:
             self.player.Stop()
-        elif 'Next' in response:
+        elif "Next" in response:
             self.player.play_next()
-        elif 'Previous' in response:
+        elif "Previous" in response:
             self.player.play_previous()
 
     @log
@@ -281,8 +302,8 @@ class Window(Gtk.ApplicationWindow):
             GLib.idle_add(i.populate)
 
     @log
-    def _on_select_all(self, action, param):
-        if self.toolbar._selectionMode is False:
+    def _select_all(self, action=None, param=None):
+        if not self.toolbar.selection_mode:
             return
         if self.toolbar._state == ToolbarState.MAIN:
             view = self._stack.get_visible_child()
@@ -292,7 +313,9 @@ class Window(Gtk.ApplicationWindow):
         view.select_all()
 
     @log
-    def _on_select_none(self, action, param):
+    def _select_none(self, action=None, param=None):
+        if not self.toolbar.selection_mode:
+            return
         if self.toolbar._state == ToolbarState.MAIN:
             view = self._stack.get_visible_child()
             view.unselect_all()
@@ -303,60 +326,80 @@ class Window(Gtk.ApplicationWindow):
     @log
     def _on_key_press(self, widget, event):
         modifiers = Gtk.accelerator_get_default_mod_mask()
-        event_and_modifiers = (event.state & modifiers)
+        modifiers = (event.state & modifiers)
 
-        if event_and_modifiers != 0:
+        if modifiers != 0:
+            control_mask = Gdk.ModifierType.CONTROL_MASK
+            shift_mask = Gdk.ModifierType.SHIFT_MASK
+            mod1_mask = Gdk.ModifierType.MOD1_MASK
+
+            if (event.keyval == Gdk.KEY_a
+                    and modifiers == control_mask):
+                self._select_all()
+            if (event.keyval == Gdk.KEY_A
+                    and modifiers == (shift_mask | control_mask)):
+                self._select_none()
             # Open search bar on Ctrl + F
-            if (event.keyval == Gdk.KEY_f and
-                    event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+            if ((event.keyval == Gdk.KEY_f and modifiers == control_mask)
+                    and not self.views[View.PLAYLIST].rename_active
+                    and self.toolbar._state != ToolbarState.SEARCH_VIEW):
                 self.toolbar.searchbar.toggle()
             # Play / Pause on Ctrl + SPACE
             if (event.keyval == Gdk.KEY_space
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+                    and modifiers == control_mask):
                 self.player.play_pause()
             # Play previous on Ctrl + B
             if (event.keyval == Gdk.KEY_b
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+                    and modifiers == control_mask):
                 self.player.play_previous()
             # Play next on Ctrl + N
             if (event.keyval == Gdk.KEY_n
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+                    and modifiers == control_mask):
                 self.player.play_next()
             # Toggle repeat on Ctrl + R
             if (event.keyval == Gdk.KEY_r
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+                    and modifiers == control_mask):
                 if self.player.get_repeat_mode() == RepeatType.SONG:
                     self.player.set_repeat_mode(RepeatType.NONE)
                 else:
                     self.player.set_repeat_mode(RepeatType.SONG)
             # Toggle shuffle on Ctrl + S
             if (event.keyval == Gdk.KEY_s
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+                    and modifiers == control_mask):
                 if self.player.get_repeat_mode() == RepeatType.SHUFFLE:
                     self.player.set_repeat_mode(RepeatType.NONE)
                 else:
                     self.player.set_repeat_mode(RepeatType.SHUFFLE)
             # Go back from Album view on Alt + Left
-            if (event.keyval == Gdk.KEY_Left and
-                    event_and_modifiers == Gdk.ModifierType.MOD1_MASK):
+            if (event.keyval == Gdk.KEY_Left
+                    and modifiers == mod1_mask):
                 self.toolbar.on_back_button_clicked()
-            # Go to Albums view on Ctrl + 1
-            if (event.keyval == Gdk.KEY_1
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
-                self._toggle_view(0, 0)
-            # Go to Artists view on Ctrl + 2
-            if (event.keyval == Gdk.KEY_2
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
-                self._toggle_view(0, 1)
-            # Go to Songs view on Ctrl + 3
-            if (event.keyval == Gdk.KEY_3
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
-                self._toggle_view(0, 2)
-            # Go to Playlists view on Ctrl + 4
-            if (event.keyval == Gdk.KEY_4
-                    and event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
-                self._toggle_view(0, 3)
+            if ((event.keyval in [Gdk.KEY_1, Gdk.KEY_KP_1])
+                    and modifiers == control_mask):
+                self._toggle_view(View.ALBUM)
+            if ((event.keyval in [Gdk.KEY_2, Gdk.KEY_KP_2])
+                    and modifiers == control_mask):
+                self._toggle_view(View.ARTIST)
+            if ((event.keyval in [Gdk.KEY_3, Gdk.KEY_KP_3])
+                    and modifiers == control_mask):
+                self._toggle_view(View.SONG)
+            if ((event.keyval in [Gdk.KEY_4, Gdk.KEY_KP_4])
+                    and modifiers == control_mask):
+                self._toggle_view(View.PLAYLIST)
         else:
+            if (event.keyval == Gdk.KEY_AudioPlay
+                    or event.keyval == Gdk.KEY_AudioPause):
+                self.player.play_pause()
+
+            if event.keyval == Gdk.KEY_AudioStop:
+                self.player.Stop()
+
+            if event.keyval == Gdk.KEY_AudioPrev:
+                self.player.play_prev()
+
+            if event.keyval == Gdk.KEY_AudioNext:
+                self.player.play_next()
+
             child = self._stack.get_visible_child()
             if (event.keyval == Gdk.KEY_Delete
                     and child == self.views[View.PLAYLIST]):
@@ -365,7 +408,7 @@ class Window(Gtk.ApplicationWindow):
             if event.keyval == Gdk.KEY_Escape:
                 self.toolbar.searchbar.reveal(False)
                 # Also disable selection
-                if self.toolbar._selectionMode:
+                if self.toolbar.selection_mode:
                     self.toolbar.set_selection_mode(False)
 
         # Open the search bar when typing printable chars.
@@ -373,9 +416,10 @@ class Window(Gtk.ApplicationWindow):
         if ((not self.toolbar.searchbar.get_search_mode()
                 and not event.keyval == Gdk.KEY_space)
                 and GLib.unichar_isprint(chr(key_unic))
-                and (event_and_modifiers == Gdk.ModifierType.SHIFT_MASK
-                    or event_and_modifiers == 0)
-                and not self.views[View.PLAYLIST].rename_active):
+                and (modifiers == Gdk.ModifierType.SHIFT_MASK
+                     or modifiers == 0)
+                and not self.views[View.PLAYLIST].rename_active
+                and self.toolbar._state != ToolbarState.SEARCH_VIEW):
             self.toolbar.searchbar.reveal(True)
 
     @log
@@ -430,8 +474,8 @@ class Window(Gtk.ApplicationWindow):
             self.views[View.PLAYLIST].disable_rename_playlist()
 
     @log
-    def _toggle_view(self, btn, i):
-        self._stack.set_visible_child(self.views[i])
+    def _toggle_view(self, view_enum):
+        self._stack.set_visible_child(self.views[view_enum])
 
     @log
     def _on_search_toggled(self, button, data=None):
@@ -450,12 +494,12 @@ class Window(Gtk.ApplicationWindow):
                     and child != self.curr_view._artist_albums_widget):
                 self._stack.set_visible_child(self.views[View.ALBUM])
 
-            if self.toolbar._selectionMode:
+            if self.toolbar.selection_mode:
                 self.toolbar.set_selection_mode(False)
 
     @log
     def _on_selection_mode_changed(self, widget, data=None):
-        if self.toolbar._selectionMode is False:
+        if self.toolbar.selection_mode is False:
             self._on_changes_pending()
         else:
             child = self._stack.get_visible_child()
